@@ -11,13 +11,14 @@ import logging
 import operator
 import random
 import zlib
-import json
 
 import newrelic.packages.six as six
 
 from newrelic.core.internal_metrics import (internal_trace, InternalTrace,
         internal_metric)
 
+from ..common.encoding_utils import json_encode
+
 _logger = logging.getLogger(__name__)
 
 class ApdexStats(list):
@@ -282,6 +283,10 @@ class StatsEngine(object):
     def settings(self):
         return self.__settings
 
+    @property
+    def stats_table(self):
+        return self.__stats_table
+
     @property
     def metric_ids(self):
         """Returns a reference to the dictionary containing the mappings
@@ -647,6 +652,24 @@ class StatsEngine(object):
                     settings.analytics_events.transactions.enabled):
 
                 record = {}
+                params = {}
+
+                # First remember users custom parameters. We only
+                # retain any which have string type for key and
+                # string or numeric for value.
+
+                if settings.analytics_events.capture_attributes:
+                    for key, value in transaction.custom_params.items():
+                        if not isinstance(key, six.string_types):
+                            continue
+                        if (not isinstance(value, six.string_types) and
+                                not isinstance(value, float) and
+                                not isinstance(value, six.integer_types)):
+                            continue
+                        params[key] = value
+
+                # Now we add the agents own values so they
+                # overwrite users values if same key name used.
 
                 name = self.__sampled_data_set.intern(transaction.path)
 
@@ -669,7 +692,7 @@ class StatsEngine(object):
                 _update_entry('Database/all', 'databaseDuration')
                 _update_entry('Memcache/all', 'memcacheDuration')
 
-                self.__sampled_data_set.add([record])
+                self.__sampled_data_set.add([record, params])
 
     @internal_trace('Supportability/StatsEngine/Calls/metric_data')
     def metric_data(self, normalizer=None):
@@ -774,7 +797,7 @@ class StatsEngine(object):
             if explain_plan:
                 params['explain_plan'] = explain_plan
 
-            json_data = json.dumps(params, default=lambda o: list(iter(o)))
+            json_data = json_encode(params)
 
             params_data = base64.standard_b64encode(
                     zlib.compress(six.b(json_data)))
@@ -782,10 +805,16 @@ class StatsEngine(object):
             if six.PY3:
                 params_data = params_data.decode('Latin-1')
 
+            # Limit the length of any SQL that is reported back.
+
+            limit = self.__settings.agent_limits.sql_query_length_maximum
+
+            sql = node.slow_sql_node.formatted[:limit]
+
             data = [node.slow_sql_node.path,
                     node.slow_sql_node.request_uri,
                     node.slow_sql_node.identifier,
-                    node.slow_sql_node.formatted,
+                    sql,
                     node.slow_sql_node.metric,
                     node.call_count,
                     node.total_call_time * 1000,
@@ -841,7 +870,7 @@ class StatsEngine(object):
             with InternalTrace('Supportability/StatsEngine/JSON/Encode/'
                                'transaction_sample_data'):
 
-                json_data = json.dumps(data, default=lambda o: list(iter(o)))
+                json_data = json_encode(data)
 
             internal_metric('Supportability/StatsEngine/ZLIB/Bytes/'
                             'transaction_sample_data', len(json_data))
@@ -912,7 +941,7 @@ class StatsEngine(object):
         with InternalTrace('Supportability/StatsEngine/JSON/Encode/'
                 'transaction_sample_data'):
 
-            json_data = json.dumps(data, default=lambda o: list(iter(o)))
+            json_data = json_encode(data)
 
         internal_metric('Supportability/StatsEngine/ZLIB/Bytes/'
                 'transaction_sample_data', len(json_data))
